==> RecordLinkage_0.3-5.zip: RecordLinkage/doc/WeightBased.R <==
###################################################
### chunk number 1: 
###################################################
#line 4 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
options(width=50)


###################################################
### chunk number 2: 
###################################################
#line 26 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
library(RecordLinkage)
library(xtable)


###################################################
### chunk number 3: 
###################################################
#line 35 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
data(RLdata500)
RLdata500[1:5,]


###################################################
### chunk number 4: 
###################################################
#line 46 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
pairs=compare.dedup(RLdata500,identity=identity.RLdata500,blockfld=list(c(5,6),c(6,7),c(5,7)))
summary(pairs)


###################################################
### chunk number 5: 
###################################################
#line 56 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
pairs=emWeights(pairs)
hist(pairs$Wdata, plot=FALSE)


###################################################
### chunk number 6: 
###################################################
#line 71 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
getPairs(pairs,30,20)


###################################################
### chunk number 7: 
###################################################
#line 74 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
getPairs(pairs,30,20)[23:36,]


###################################################
### chunk number 8: 
###################################################
#line 77 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
pairs=emClassify(pairs, threshold.upper=24, threshold.lower=-7)
summary(pairs)


###################################################
### chunk number 9: 
###################################################
#line 87 "d:/Rcompile/CRANpkg/local/2.12/RecordLinkage/inst/doc/WeightBased.rnw"
possibles <- getPairs(pairs, show="possible")
possibles[1:6,]
links=getPairs(pairs,show="links", single.rows=TRUE)
link_ids <- links[, c("id1", "id2")]
link_ids

==> RecordLinkage_0.4-1.zip: RecordLinkage/doc/WeightBased.R <==
### R code from vignette source 'WeightBased.rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: WeightBased.rnw:3-4
###################################################
options(width=50)


###################################################
### code chunk number 2: WeightBased.rnw:25-27
###################################################
library(RecordLinkage)
library(xtable)


###################################################
### code chunk number 3: WeightBased.rnw:34-36
###################################################
data(RLdata500)
RLdata500[1:5,]


###################################################
### code chunk number 4: WeightBased.rnw:45-47
###################################################
pairs=compare.dedup(RLdata500,identity=identity.RLdata500,blockfld=list(c(5,6),c(6,7),c(5,7)))
summary(pairs)


###################################################
### code chunk number 5: WeightBased.rnw:55-57
###################################################
pairs=emWeights(pairs)
hist(pairs$Wdata, plot=FALSE)


###################################################
### code chunk number 6: WeightBased.rnw:70-71
###################################################
getPairs(pairs,30,20)


###################################################
### code chunk number 7: WeightBased.rnw:73-74
###################################################
getPairs(pairs,30,20)[23:36,]


###################################################
### code chunk number 8: WeightBased.rnw:76-78
###################################################
pairs=emClassify(pairs, threshold.upper=24, threshold.lower=-7)
summary(pairs)


###################################################
### code chunk number 9: WeightBased.rnw:86-92
###################################################
possibles <- getPairs(pairs, show="possible")
possibles[1:6,]
links=getPairs(pairs,show="links", single.rows=TRUE)
link_ids <- links[, c("id1", "id2")]
link_ids
